@@ -1,24 +1,18 @@
 # coding: utf-8
 
-from __future__ import print_function, absolute_import, division, unicode_literals
-
 _package_data = dict(
     full_package_name='ruamel.std.pathlib',
-    version_info=(0, 6, 4),
-    __version__='0.6.4',
+    version_info=(0, 8, 0),
+    __version__='0.8.0',
     author='Anthon van der Neut',
     author_email='a.van.der.neut@ruamel.eu',
     since=2013,
-    description='improvements over the standard pathlib module and pathlib2 package',
+    description='improvements over the standard pathlib module',
     entry_points=None,
-    extras_require={
-        ':python_version<="3.4"': ['pathlib2', ],
-    },
     license='MIT License',
     universal=True,
-    tox=dict(
-        env='*',
-    ),
+    tox=dict(env='*',),
+    print_allowed=True,
 )
 # pathlib2 for 3.4 -> expanduser added
 
@@ -31,12 +25,19 @@ import os       # NOQA
 import sys      # NOQA
 import inspect  # NOQA
 
-if sys.version_info < (3, 5):
-    # 3.4 e.g has no expanduser()
-    from pathlib2 import *  # NOQA
-    FileNotFoundError = IOError
-else:
-    from pathlib import *   # NOQA
+from pathlib import *  # NOQA
+
+
+if sys.version_info < (3, 9):
+
+    def _is_relative_to(self, other):
+        try:
+            self.relative_to(other)
+            return True
+        except ValueError:
+            return False
+
+    Path.is_relative_to = _is_relative_to
 
 
 class DirStack(object):
@@ -62,16 +63,6 @@ def pushd(d):
 def popd():
     _dir_stack.popd()
 
-# pathlib 0.8 was not compatible with pathlib in python 3.4,
-# but 0.97 is
-# should check here but there is no version number in pathlib ...
-# switched to pathlib2 which aims at compatibility
-#
-#     @property
-#     def root_stem(self):
-#         """The final path component, minus suffices."""
-#         return self.name.split('.', 1)[0]
-
 
 # just for some sanity
 Path.remove = Path.unlink
@@ -79,6 +70,7 @@ Path.remove = Path.unlink
 
 def _rmtree(self):
     import shutil
+
     assert self.is_dir()
     shutil.rmtree(str(self))
 
@@ -96,18 +88,16 @@ Path.chdir = _chdir
 
 def _hash(self, typ=None, size=-1):
     """hash of the contents, typ can be any of the hashlib.new() acceptable strings
-    if size is provided and positive only read that amount of bytes from the start of the file
+    if size is provided and non-negative only read that amount of bytes from the start
+    of the file
     """
     import hashlib
+
     if typ is None:
         typ = 'sha224'
     with self.open(mode='rb') as f:
         data = f.read(size)
-    try:
-        h = hashlib.new(typ, data=data)
-    except:
-        h = hashlib.new(typ)
-        h.update(data)
+    h = hashlib.new(typ, data=data)
     return h
 
 
@@ -116,6 +106,7 @@ Path.hash = _hash
 
 def _copy(self, target):
     import shutil
+
     assert self.is_file()
     shutil.copy(str(self), str(target))
 
@@ -131,7 +122,6 @@ def _utime(self, atime, mtime):
 Path.utime = _utime
 
 
-
 # #
 # # - If the check level is set at 1, any calls that are issued with strings that
 # #     could be changed are logged (to the console), those are the positions where
@@ -163,9 +153,11 @@ class PathLibConversionHelper(object):
     maybe look at https://github.com/mikeorr/Unipath#comparision-with-osospathshutil-and-pathpy
     and incorporate
     """
+
     def __init__(self, check=0):
         class Container(object):
             pass
+
         self._check = check
         self._usage = {}
         path = self.path = Container()
@@ -184,7 +176,7 @@ class PathLibConversionHelper(object):
             return
         caller = inspect.stack()[2]
         t = caller[1], caller[2], comment, vt
-        count = self._usage.setdefault(t, [0, ])
+        count = self._usage.setdefault(t, [0])
         count[0] += 1
         if self._check > 1 and count[0] == 1:
             print('{2} [{0}:{1} / Path {3}]'.format(*t))
@@ -209,6 +201,7 @@ class PathLibConversionHelper(object):
             old_name.rename(new_name)  # rename works with strings and Path
         else:
             os.rename(old_name, str(new_name))
+
     # os.rename
     # os.getcwd
     # os.path.expanduser
@@ -240,7 +233,7 @@ class PathLibConversionHelper(object):
             return os.path.dirname(file_name)
 
     def _path_getmtime(self, file_name):
-        self.add_usage(file_name, 'update .path.getmtime to use Path.parent')
+        self.add_usage(file_name, 'update .path.getmtime to use Path.stat().st_mtime')
         if isinstance(file_name, Path):
             return file_name.stat().st_mtime
         else:
@@ -269,8 +262,8 @@ class PathLibConversionHelper(object):
 
     def _path_splitext(self, path):
         self.add_usage(
-            path,
-            'update .path.splitext to use Path.parent / Path.stem + Path.suffix')
+            path, 'update .path.splitext to use Path.parent / Path.stem + Path.suffix'
+        )
         if isinstance(path, Path):
             return path.parent / path.stem, path.suffix
         else:
@@ -278,9 +271,7 @@ class PathLibConversionHelper(object):
 
     def chdir(self, path):
         """replaces: os.chdir()"""
-        self.add_usage(
-            path,
-            'update .chdir to use Path.chdir() or os.chdir(str(Path))')
+        self.add_usage(path, 'update .chdir to use Path.chdir() or os.chdir(str(Path))')
         if isinstance(path, Path):
             return path.chdir()
         else:
@@ -290,9 +281,7 @@ class PathLibConversionHelper(object):
 
     def rmdir(self, path):
         """replaces: os.rmdir()"""
-        self.add_usage(
-            path,
-            'update .rmdir to use Path.rmdir() or os.rmdir(str(Path))')
+        self.add_usage(path, 'update .rmdir to use Path.rmdir() or os.rmdir(str(Path))')
         if isinstance(path, Path):
             return path.rmdir()
         else:
@@ -300,16 +289,12 @@ class PathLibConversionHelper(object):
 
     def makedirs(self, path, *args, **kw):
         """replaces: os.makedirs()"""
-        self.add_usage(
-            path,
-            'update .makedirs to use Path.mkdir()')
+        self.add_usage(path, 'update .makedirs to use Path.mkdir()')
         os.makedirs(str(path), *args, **kw)
 
     def remove(self, path):
         """replaces: os.remove()"""
-        self.add_usage(
-            path,
-            'update .chdir to use Path.chdir() or os.chdir(str(Path))')
+        self.add_usage(path, 'update .chdir to use Path.chdir() or os.chdir(str(Path))')
         if isinstance(path, Path):
             return path.remove()
         else:
@@ -322,6 +307,7 @@ class PathLibConversionHelper(object):
     def glob(self, pattern):
         """replaces: glob.glob()"""
         import glob
+
         self.add_usage(path, 'update .glob to use Path.glob()')
         if isinstance(pattern, Path):
             return [Path(fn) for fn in glob.glob(str(pattern))]
@@ -332,8 +318,8 @@ class PathLibConversionHelper(object):
     def rmtree(self, path):
         """replaces: shutil.rmtree()"""
         import shutil
-        self.add_usage(
-            path, 'update .rmtree to use Path.rmtree() or shutil.rmtree(str(Path))')
+
+        self.add_usage(path, 'update .rmtree to use Path.rmtree() or shutil.rmtree(str(Path))')
         if isinstance(path, Path):
             return path.rmtree()
         else:
@@ -343,8 +329,10 @@ class PathLibConversionHelper(object):
     def copy(self, src, dst):
         """replaces: shutil.copy()"""
         import shutil
+
         self.add_usage(
-            src, 'update .copy to use Path.copy() or shutil.copy(str(src), str(dst))')
+            src, 'update .copy to use Path.copy() or shutil.copy(str(src), str(dst))'
+        )
         if isinstance(src, Path):
             return src.copy(dst)
         else:
@@ -362,6 +350,7 @@ class PathLibConversionHelper(object):
     def mkstemp(self, suffix="", prefix=None, dir=None, text=False):
         """replaces: tempfile.mkstemp()"""
         import tempfile
+
         if prefix is None:
             prefix = tempfile.template
         self.add_usage(dir, 'update .mkstemp to use Path.mkstemp()')
